==> Donphan-4.8.0.tar.gz: Donphan-4.8.0/donphan/__init__.py <==
"""
MIT License

Copyright (c) 2019-present Josh B

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

__title__ = "donphan"
__author__ = "Bijij"
__license__ = "MIT"
__copyright__ = "Copyright 2020-Present Bijij"
__version__ = "4.8.0"

from typing import TYPE_CHECKING

from ._column import *
from ._connection import *
from ._custom_types import *
from ._enums import *
from ._join import *
from ._table import *
from ._view import *
from . import utils as utils

if TYPE_CHECKING:
    from . import _types as SQLType
else:
    from ._sqltype import *

==> Donphan-4.10.3.tar.gz: Donphan-4.10.3/donphan/__init__.py <==
"""
MIT License

Copyright (c) 2019-present Josh B

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

__title__ = "donphan"
__author__ = "Bijij"
__license__ = "MIT"
__copyright__ = "Copyright 2020-Present Bijij"
__version__ = "4.10.3"

from typing import TYPE_CHECKING

from ._column import *
from ._connection import *
from ._custom_types import *
from ._enums import *
from ._join import *
from ._table import *
from ._view import *
from . import utils as utils

if TYPE_CHECKING:
    from . import _types as _SQLType  # type: ignore

    SQLType = _SQLType
else:
    from ._sqltype import *
